@@ -1,6 +1,6 @@
 package Hubot::Scripts::eval;
 {
-  $Hubot::Scripts::eval::VERSION = '0.0.4';
+  $Hubot::Scripts::eval::VERSION = '0.0.5';
 }
 use strict;
 use warnings;
@@ -12,7 +12,7 @@ sub load {
         qr/^eval:? on *$/i,
         sub {
             my $msg = shift;
-            $robot->brain->{eval}{ $msg->message->user->{name} }{recording} = 1;
+            $robot->brain->{data}{eval}{ $msg->message->user->{name} }{recording} = 1;
             $msg->send( 'OK, recording '
                   . $msg->message->user->{name}
                   . "'s codes for evaluate" );
@@ -24,7 +24,7 @@ sub load {
         sub {
             my $msg  = shift;
             my $code = join "\n",
-              @{ $robot->brain->{eval}{ $msg->message->user->{name} }{code} ||=
+              @{ $robot->brain->{data}{eval}{ $msg->message->user->{name} }{code} ||=
                   [] };
             $msg->http('http://api.dan.co.jp/lleval.cgi')
               ->query( { s => "#!/usr/bin/perl\n$code" } )->get(
@@ -32,10 +32,10 @@ sub load {
                     my ( $body, $hdr ) = @_;
                     return if ( !$body || $hdr->{Status} !~ m/^2/ );
                     my $data = decode_json($body);
-                    $msg->send( $data->{stdout} || $data->{stderr} );
+                    $msg->send( split /\n/, $data->{stdout} || $data->{stderr} );
                 }
               );
-            delete $robot->brain->{eval}{ $msg->message->user->{name} };
+            delete $robot->brain->{data}{eval}{ $msg->message->user->{name} };
         }
     );
 
@@ -43,7 +43,7 @@ sub load {
         qr/^eval:? cancel *$/i,
         sub {
             my $msg = shift;
-            delete $robot->brain->{eval}{ $msg->message->user->{name} };
+            delete $robot->brain->{data}{eval}{ $msg->message->user->{name} };
             $msg->send( 'canceled '
                   . $msg->message->user->{name}
                   . "'s evaluation recording" );
@@ -62,7 +62,7 @@ sub load {
                         my ( $body, $hdr ) = @_;
                         return if ( !$body || $hdr->{Status} !~ m/^2/ );
                         my $data = decode_json($body);
-                        $msg->send( $data->{stdout} || $data->{stderr} );
+                        $msg->send( split /\n/, $data->{stdout} || $data->{stderr} );
                     }
                   );
             }
@@ -72,11 +72,11 @@ sub load {
     $robot->catchAll(
         sub {
             my $msg = shift;
-            if ( $robot->brain->{eval}{ $msg->message->user->{name} }{recording}
+            if ( $robot->brain->{data}{eval}{ $msg->message->user->{name} }{recording}
               )
             {
                 if ( ref $msg->message eq 'Hubot::TextMessage' ) {
-                    push @{ $robot->brain->{eval}{ $msg->message->user->{name} }
+                    push @{ $robot->brain->{data}{eval}{ $msg->message->user->{name} }
                           {code} ||= [] }, $msg->message->text
                       if $msg->message->text !~ /^eval:? on *$/;
                 }
@@ -94,8 +94,9 @@ Hubot::Scripts::eval
 =head1 SYNOPSIS
 
     eval <code> - evaluate <code> and show the result
-    eval on - starting record
+    eval on - start recording
     eval off|finish|done - evaluate recorded <code> and show the result
+    eval cancel - cancel recording
 
 =head1 AUTHOR
 
